@@ -1,6 +1,6 @@
 package Pcore::App::Sphinx;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::App::Alien];
 
@@ -42,7 +42,7 @@ around cli_opt => sub ( $orig, $self ) {
 };
 
 sub _build_sphinx_ver ($self) {
-    return $self->cfg->{SPHINX}->{SPHINX_VER} || $PROC->{CFG}->{SPHINX}->{SPHINX_VER};
+    return $self->cfg->{SPHINX}->{SPHINX_VER} || $ENV->{CFG}->{SPHINX}->{SPHINX_VER};
 }
 
 # APP
@@ -70,8 +70,8 @@ around _build_cfg => sub ( $orig, $self ) {
                 SERVER => {
                     searchd => {
                         listen                       => q[9306:mysql41],
-                        log                          => $PROC->{LOG_DIR} . $self->name . '-searchd.log',
-                        query_log                    => $PROC->{LOG_DIR} . $self->name . '-searchd-query.log',
+                        log                          => $ENV->{LOG_DIR} . $self->name . '-searchd.log',
+                        query_log                    => $ENV->{LOG_DIR} . $self->name . '-searchd-query.log',
                         read_timeout                 => 5,
                         client_timeout               => 300,
                         max_children                 => 30,
@@ -208,13 +208,13 @@ around app_build => sub ( $orig, $self ) {
             }
 
             # sphinx
-            P->sys->system( q[wget -O - http://sphinxsearch.com/files/sphinx-] . $self->sphinx_ver . qq[-release.tar.gz | tar -C $PROC->{TEMP_DIR} -xzvf -] );
+            P->sys->system( q[wget -O - http://sphinxsearch.com/files/sphinx-] . $self->sphinx_ver . qq[-release.tar.gz | tar -C $ENV->{TEMP_DIR} -xzvf -] );
 
             # libstemmer
-            P->sys->system( qq[wget -O - http://snowball.tartarus.org/dist/libstemmer_c.tgz | tar -C $PROC->{TEMP_DIR}sphinx-] . $self->sphinx_ver . q[-release -xzvf -] );
+            P->sys->system( qq[wget -O - http://snowball.tartarus.org/dist/libstemmer_c.tgz | tar -C $ENV->{TEMP_DIR}sphinx-] . $self->sphinx_ver . q[-release -xzvf -] );
 
             {
-                my $chdir_guard = P->file->chdir( $PROC->{TEMP_DIR} . 'sphinx-' . $self->sphinx_ver . q[-release] ) or die;
+                my $chdir_guard = P->file->chdir( $ENV->{TEMP_DIR} . 'sphinx-' . $self->sphinx_ver . q[-release] ) or die;
 
                 P->sys->system( q[./configure], q[--prefix=] . $self->alien_dir, q[--with-mysql], q[--with-libstemmer], q[--with-libexpat], q[--with-iconv], q[--enable-id64], qq[--with-re2-includes=$re2_prefix] );
 
