@@ -1,6 +1,6 @@
 package Pcore::Handle::Sphinx;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::Handle::MySQL];
 
